@@ -25,7 +25,7 @@ class RTParser(object):
             ...     3
             ... eggs:'''
             >>> RTParser.parse(body, decode)
-            [[('spam', '1'), ('ham', '2, 3'), ('eggs', '')]]
+            [[('spam', '1'), ('ham', '2,\\n3'), ('eggs', '')]]
             >>> RTParser.parse('# spam 1 does not exist.', decode)
             Traceback (most recent call last):
             ...
@@ -101,7 +101,7 @@ class RTParser(object):
             ... a -- b
             ... '''
             >>> RTParser.build(body)
-            [['# a b', 'spam: 1', 'ham: 2, 3'], ['# c', 'spam: 4', 'ham:'], ['a -- b']]
+            [['# a\\nb', 'spam: 1', 'ham: 2,\\n3'], ['# c', 'spam: 4', 'ham:'], ['a -- b']]
         """
         def build_section(section):
             logic_lines = []
@@ -109,7 +109,7 @@ class RTParser(object):
                 if cls.HEADER.match(line):
                     continue
                 if line[0].isspace():
-                    logic_lines[-1] += ' ' + line.strip(' ')
+                    logic_lines[-1] += '\n' + line.strip(' ')
                 else:
                     logic_lines.append(line)
             return logic_lines
